/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: FWObjectReference.h,v 1.3 2006/09/10 22:40:36 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef  __FWOBJECTREF_HH_FLAG__
#define  __FWOBJECTREF_HH_FLAG__

#include <fwbuilder/FWReference.h>

namespace libfwbuilder
{

class ObjectGroup;

/**
 * This class represents object reference.
 */
class FWObjectReference : public FWReference
{
    public:

    DECLARE_FWOBJECT_SUBTYPE(FWObjectReference);

    FWObjectReference();
    FWObjectReference(const FWObject *root,bool prepopulate);

    void setPointer(FWObject *o);
    void setPointer(ObjectGroup *o);

};

}

#endif // _FWOBJECT_HH
